==> jc-1.4.0.tar.gz: javax/swing/text/StyledEditorKit.h <==
// public class javax.swing.text.StyledEditorKit

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b73385988de3a8cb javax_swing_text_DefaultEditorKit
// @dep_class 24d74fb32d567cd2 javax_swing_text_EditorKit
// @dep_class 89039d3a7c79ae9a javax_swing_text_StyledEditorKit

// header file dependencies
// @dep_header javax_swing_text_DefaultEditorKit

#include "javax/swing/text/DefaultEditorKit.h"

#ifndef _JC_javax_swing_text_StyledEditorKit_H_
#define _JC_javax_swing_text_StyledEditorKit_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_swing_JEditorPane$object;
struct _jc_javax_swing_text_Document$object;
struct _jc_javax_swing_text_Element$object;
struct _jc_javax_swing_text_MutableAttributeSet$object;
struct _jc_javax_swing_text_ViewFactory$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyledEditorKit$sub_refs	_jc_javax_swing_text_StyledEditorKit$sub_refs;
typedef struct _jc_javax_swing_text_StyledEditorKit$sub_nonrefs	_jc_javax_swing_text_StyledEditorKit$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit$refs	_jc_javax_swing_text_StyledEditorKit$refs;
typedef struct _jc_javax_swing_text_StyledEditorKit$nonrefs	_jc_javax_swing_text_StyledEditorKit$nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit$object	_jc_javax_swing_text_StyledEditorKit$object;

typedef struct _jc_javax_swing_text_StyledEditorKit$fields_struct	_jc_javax_swing_text_StyledEditorKit$fields_struct;
typedef const struct _jc_javax_swing_text_StyledEditorKit$vmethods	_jc_javax_swing_text_StyledEditorKit$vmethods;
typedef const struct _jc_javax_swing_text_StyledEditorKit$vtable	_jc_javax_swing_text_StyledEditorKit$vtable;
typedef const struct _jc_javax_swing_text_StyledEditorKit$vtype	_jc_javax_swing_text_StyledEditorKit$vtype;

// Class fields structure
struct _jc_javax_swing_text_StyledEditorKit$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_text_StyledEditorKit$fields_struct _jc_javax_swing_text_StyledEditorKit$class_fields;

// Constructors
extern void _jc_javax_swing_text_StyledEditorKit$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_javax_swing_text_StyledEditorKit$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *);
extern struct _jc_object *_jc_javax_swing_text_StyledEditorKit$method$createDefaultDocument$d6c78a75f6dbe003(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *);
extern void _jc_javax_swing_text_StyledEditorKit$method$createInputAttributes$2a813ef4735e1196(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *, struct _jc_object *, struct _jc_object *);
extern void _jc_javax_swing_text_StyledEditorKit$method$deinstall$7dab4ccddea1f94f(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *, struct _jc_javax_swing_JEditorPane$object *);
extern _jc_object_array *_jc_javax_swing_text_StyledEditorKit$method$getActions$ea1976429372941d(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *);
extern struct _jc_object *_jc_javax_swing_text_StyledEditorKit$method$getCharacterAttributeRun$266e6cafc70ee42e(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *);
extern struct _jc_object *_jc_javax_swing_text_StyledEditorKit$method$getInputAttributes$34681ff9dce557a2(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *);
extern struct _jc_object *_jc_javax_swing_text_StyledEditorKit$method$getViewFactory$7b0683a833033cb8(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *);
extern void _jc_javax_swing_text_StyledEditorKit$method$install$31f2926e2645736b(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *, struct _jc_javax_swing_JEditorPane$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_StyledEditorKit$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_javax_swing_text_StyledEditorKit$method_info$createDefaultDocument$d6c78a75f6dbe003;
extern _jc_method _jc_javax_swing_text_StyledEditorKit$method_info$createInputAttributes$2a813ef4735e1196;
extern _jc_method _jc_javax_swing_text_StyledEditorKit$method_info$deinstall$7dab4ccddea1f94f;
extern _jc_method _jc_javax_swing_text_StyledEditorKit$method_info$getActions$ea1976429372941d;
extern _jc_method _jc_javax_swing_text_StyledEditorKit$method_info$getCharacterAttributeRun$266e6cafc70ee42e;
extern _jc_method _jc_javax_swing_text_StyledEditorKit$method_info$getInputAttributes$34681ff9dce557a2;
extern _jc_method _jc_javax_swing_text_StyledEditorKit$method_info$getViewFactory$7b0683a833033cb8;
extern _jc_method _jc_javax_swing_text_StyledEditorKit$method_info$install$31f2926e2645736b;

// Virtual methods structure
struct _jc_javax_swing_text_StyledEditorKit$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *);
	struct _jc_object	*(*createDefaultDocument$d6c78a75f6dbe003)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *);
	void	(*createInputAttributes$2a813ef4735e1196)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *, struct _jc_object *, struct _jc_object *);
	void	(*deinstall$7dab4ccddea1f94f)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *, struct _jc_javax_swing_JEditorPane$object *);
	_jc_object_array	*(*getActions$ea1976429372941d)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *);
	struct _jc_object	*(*getCharacterAttributeRun$266e6cafc70ee42e)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *);
	struct _jc_object	*(*getInputAttributes$34681ff9dce557a2)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *);
	struct _jc_object	*(*getViewFactory$7b0683a833033cb8)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *);
	void	(*install$31f2926e2645736b)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *, struct _jc_javax_swing_JEditorPane$object *);
};

// Vtable
struct _jc_javax_swing_text_StyledEditorKit$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_EditorKit$vmethods	javax_swing_text_EditorKit;
	_jc_javax_swing_text_DefaultEditorKit$vmethods	javax_swing_text_DefaultEditorKit;
	_jc_javax_swing_text_StyledEditorKit$vmethods	javax_swing_text_StyledEditorKit;
};

// Vtype
struct _jc_javax_swing_text_StyledEditorKit$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyledEditorKit$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit$sub_refs {
	struct _jc_object	*currentRun;
	struct _jc_object	*currentParagraph;
	struct _jc_object	*inputAttributes;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit$refs {
    _jc_javax_swing_text_StyledEditorKit$sub_refs	javax_swing_text_StyledEditorKit;
    _jc_javax_swing_text_DefaultEditorKit$sub_refs	javax_swing_text_DefaultEditorKit;
    _jc_javax_swing_text_EditorKit$sub_refs	javax_swing_text_EditorKit;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_EditorKit$sub_nonrefs	javax_swing_text_EditorKit;
    _jc_javax_swing_text_DefaultEditorKit$sub_nonrefs	javax_swing_text_DefaultEditorKit;
    _jc_javax_swing_text_StyledEditorKit$sub_nonrefs	javax_swing_text_StyledEditorKit;
};

// Object instance structure
struct _jc_javax_swing_text_StyledEditorKit$object {
	_jc_javax_swing_text_StyledEditorKit$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyledEditorKit$vtype	*vtype;
	_jc_javax_swing_text_StyledEditorKit$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyledEditorKit$vtype _jc_javax_swing_text_StyledEditorKit$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyledEditorKit, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyledEditorKit$class_object;

#endif	/* _JC_javax_swing_text_StyledEditorKit_H_ */

==> jc-1.4.5.tar.gz: javax/swing/text/StyledEditorKit.h <==
// public class javax.swing.text.StyledEditorKit

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class caa20ff98450f590 javax_swing_text_DefaultEditorKit
// @dep_class 24d74fb32d567cd2 javax_swing_text_EditorKit
// @dep_class 89039d3a7c79ae9a javax_swing_text_StyledEditorKit

// header file dependencies
// @dep_header javax_swing_text_DefaultEditorKit

#include "javax/swing/text/DefaultEditorKit.h"

#ifndef _JC_javax_swing_text_StyledEditorKit_H_
#define _JC_javax_swing_text_StyledEditorKit_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_swing_JEditorPane$object;
struct _jc_javax_swing_text_Document$object;
struct _jc_javax_swing_text_Element$object;
struct _jc_javax_swing_text_MutableAttributeSet$object;
struct _jc_javax_swing_text_ViewFactory$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyledEditorKit$sub_refs	_jc_javax_swing_text_StyledEditorKit$sub_refs;
typedef struct _jc_javax_swing_text_StyledEditorKit$sub_nonrefs	_jc_javax_swing_text_StyledEditorKit$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit$refs	_jc_javax_swing_text_StyledEditorKit$refs;
typedef struct _jc_javax_swing_text_StyledEditorKit$nonrefs	_jc_javax_swing_text_StyledEditorKit$nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit$object	_jc_javax_swing_text_StyledEditorKit$object;

typedef struct _jc_javax_swing_text_StyledEditorKit$fields_struct	_jc_javax_swing_text_StyledEditorKit$fields_struct;
typedef const struct _jc_javax_swing_text_StyledEditorKit$vmethods	_jc_javax_swing_text_StyledEditorKit$vmethods;
typedef const struct _jc_javax_swing_text_StyledEditorKit$vtable	_jc_javax_swing_text_StyledEditorKit$vtable;
typedef const struct _jc_javax_swing_text_StyledEditorKit$vtype	_jc_javax_swing_text_StyledEditorKit$vtype;

// Class fields structure
struct _jc_javax_swing_text_StyledEditorKit$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_text_StyledEditorKit$fields_struct _jc_javax_swing_text_StyledEditorKit$class_fields;

// Constructors
extern void _jc_javax_swing_text_StyledEditorKit$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_javax_swing_text_StyledEditorKit$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_text_StyledEditorKit$method$createDefaultDocument$d6c78a75f6dbe003(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_StyledEditorKit$method$createInputAttributes$2a813ef4735e1196(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_StyledEditorKit$method$deinstall$7dab4ccddea1f94f(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *, struct _jc_javax_swing_JEditorPane$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_swing_text_StyledEditorKit$method$getActions$ea1976429372941d(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_text_StyledEditorKit$method$getCharacterAttributeRun$266e6cafc70ee42e(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_text_StyledEditorKit$method$getInputAttributes$34681ff9dce557a2(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_text_StyledEditorKit$method$getViewFactory$7b0683a833033cb8(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_StyledEditorKit$method$install$31f2926e2645736b(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *, struct _jc_javax_swing_JEditorPane$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_StyledEditorKit$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_javax_swing_text_StyledEditorKit$method_info$createDefaultDocument$d6c78a75f6dbe003;
extern _jc_method _jc_javax_swing_text_StyledEditorKit$method_info$createInputAttributes$2a813ef4735e1196;
extern _jc_method _jc_javax_swing_text_StyledEditorKit$method_info$deinstall$7dab4ccddea1f94f;
extern _jc_method _jc_javax_swing_text_StyledEditorKit$method_info$getActions$ea1976429372941d;
extern _jc_method _jc_javax_swing_text_StyledEditorKit$method_info$getCharacterAttributeRun$266e6cafc70ee42e;
extern _jc_method _jc_javax_swing_text_StyledEditorKit$method_info$getInputAttributes$34681ff9dce557a2;
extern _jc_method _jc_javax_swing_text_StyledEditorKit$method_info$getViewFactory$7b0683a833033cb8;
extern _jc_method _jc_javax_swing_text_StyledEditorKit$method_info$install$31f2926e2645736b;

// Virtual methods structure
struct _jc_javax_swing_text_StyledEditorKit$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*createDefaultDocument$d6c78a75f6dbe003)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *) _JC_JCNI_ATTR;
	void	(*createInputAttributes$2a813ef4735e1196)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*deinstall$7dab4ccddea1f94f)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *, struct _jc_javax_swing_JEditorPane$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getActions$ea1976429372941d)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getCharacterAttributeRun$266e6cafc70ee42e)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getInputAttributes$34681ff9dce557a2)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getViewFactory$7b0683a833033cb8)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *) _JC_JCNI_ATTR;
	void	(*install$31f2926e2645736b)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit$object *, struct _jc_javax_swing_JEditorPane$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_StyledEditorKit$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_EditorKit$vmethods	javax_swing_text_EditorKit;
	_jc_javax_swing_text_DefaultEditorKit$vmethods	javax_swing_text_DefaultEditorKit;
	_jc_javax_swing_text_StyledEditorKit$vmethods	javax_swing_text_StyledEditorKit;
};

// Vtype
struct _jc_javax_swing_text_StyledEditorKit$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyledEditorKit$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit$sub_refs {
	struct _jc_object	*currentRun;
	struct _jc_object	*currentParagraph;
	struct _jc_object	*inputAttributes;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit$refs {
    _jc_javax_swing_text_StyledEditorKit$sub_refs	javax_swing_text_StyledEditorKit;
    _jc_javax_swing_text_DefaultEditorKit$sub_refs	javax_swing_text_DefaultEditorKit;
    _jc_javax_swing_text_EditorKit$sub_refs	javax_swing_text_EditorKit;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_EditorKit$sub_nonrefs	javax_swing_text_EditorKit;
    _jc_javax_swing_text_DefaultEditorKit$sub_nonrefs	javax_swing_text_DefaultEditorKit;
    _jc_javax_swing_text_StyledEditorKit$sub_nonrefs	javax_swing_text_StyledEditorKit;
};

// Object instance structure
struct _jc_javax_swing_text_StyledEditorKit$object {
	_jc_javax_swing_text_StyledEditorKit$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyledEditorKit$vtype	*vtype;
	_jc_javax_swing_text_StyledEditorKit$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyledEditorKit$vtype _jc_javax_swing_text_StyledEditorKit$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyledEditorKit, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyledEditorKit$class_object;

#endif	/* _JC_javax_swing_text_StyledEditorKit_H_ */
